# Models

Data structures returned by the API.

## Core Models

* [**Account**](account.md)
* [**Common**](common.md) (Video, Image, Date, etc.)
* [**Movie**](movie.md)
* [**Person**](person.md)
* [**Responses**](responses.md) (Generic response wrappers)
* [**Search**](search.md)
* [**TV**](tv.md)
